wagtail-content-block
=====================

Content block primitives for Wagtail, used by wagtail-content-admin. Please bear with us while we prepare more detailed documentation.

Compatibility
-------------

`wagtail-content-block`' major.minor version number indicates the Wagtail release it is compatible with. Currently this is Wagtail 4.1.x

Installation
------------

1. Install using `pip`:
  ```shell
  pip install wagtail-content-block
  ```
2. Add
   `wagtail_content_block` to your `INSTALLED_APPS` setting:
   ```python
   INSTALLED_APPS = [
     # ...
     'wagtail_content_block'
     # ...
   ]
   ```
